<?php

/**
 * @file
 * Admin include file.
 */

/**
 * Displays the form for the standard settings tab.
 *
 * @return
 *   array A structured array for use with Forms API.
 */
function wordtracker_admin_settings() {
  $apikey = variable_get('wordtracker_apikey', '');
  $form['wordtracker_apikey'] = array(
    '#type' => 'textfield',
    '#title' => t('WordTracker API Key'), 
    '#default_value' => $apikey,
    '#description' => t('You need an API key to enable keyword statistics and related phrase lookups. If you have a Wordtracker API key enter it above. To get a full API key, contact !wordtracker_link. You can also use a free !levelten_link to enable demo level access to Wordtracker statitics.',
      array(
        '!wordtracker_link' => l(t('Wordtracker'), 'http://www.wordtracker.com/api', array('attributes' => array('target', 'wordtracker'))),
        //'!levelten_link' => l(t('LevelTen SEO API key'), 'http://www.leveltendesign.com/user/0/l10seoapi', array('attributes' => array('target', 'levelten'))),
      )
    ),
  );
  
  if ($apikey) {
    $perms = variable_get('wordtracker_api_perms', '');
    if (!$perms || ($perms['apikey'] != $apikey)) {
      $perms = wordtracker_api_query_permissions();
      $perms['apikey'] = $apikey;
      //variable_set('kwresearch_api_perms',kwresearch_api_query_permissions());
      //dsm($perms);
    }
    
    $form['wordtracker_acctstatus_hdr'] = array(
      '#type' => 'markup',
      '#value' => '<h3>' . t('Account Permissions') . '</h3>', 
    );
    $statuses = array(
      'get_all_words_popularity' => t('Get all words popularity'),
      'get_embedded_phrase_popularity' => t('Get embedded phrase popularity'),
      'get_exact_phrase_popularity' => t('Get exact phrase popularity'),
      'get_plurals' => t('Get plurals'),
      'get_lateral_keyphrases' => t('Get lateral keyphrases'),
      'get_thesaurus_keyphrases' => t('Get thesaurus keyphrases'),
    );
    foreach ($statuses AS $k => $v) {
      $enabled = 'N';
      if ($perms[$k]) {
        $limit = $perms[$k]['result_limit'];
        if ($limit > 0) {
          $enabled = 'Y (limit ' . $limit . ')';
        }
      }
      $form['wordtracker_' . $k] = array(
        '#type' => 'item',
        '#title' => $v, 
        '#value' => "Enabled: " . $enabled,
      );
    }
  }

  $form['wordtracker_stats_report_options'] = array(      
    '#type' => 'fieldset',      
    '#title' => t('Stats report options'),      
    '#collapsible' => TRUE,      
    '#collapsed' => FALSE,    
  );
  $form['wordtracker_stats_report_options'] = array_merge($form['wordtracker_stats_report_options'], wordtracker_stats_report_form_options());
  
  
  return system_settings_form($form);
}

function wordtracker_free_keyword_tool_page($keyword = NULL) {
  if(!$embed_id = variable_get('wordtracker_free_embed_id', '')) {
    drupal_set_message(
      t('You will need a embed id before you can use the free keyword tool. !admin_link',
        array(
          '!admin_link' => l(t('Configure setting here'), 'admin/settings/wordtracker'),
        )
      ), 'error');
    $output = '';
  }
  else {
    $output = '
      <iframe width="673" height="557" scrolling="no" frameborder=0 src="http://freekeywordtool.wordtracker.com/themes/keyword_tool_widget_big.html?name=Test&color_b=#01679a&color_t=#ffffff&embed_id=' . $embed_id . '"></iframe>
      <br/><a href="http://www.wordtracker.com">Powered by WordStream Internet Marketing Software</a>
    ';
  }
  return $output;
}

function wordtracker_free_keyword_niche_page($keyword = NULL) {
  if(!$embed_id = variable_get('wordtracker_free_embed_id', '')) {
    drupal_set_message(
      t('You will need a embed id before you can use the free keyword tool. !admin_link',
        array(
          '!admin_link' => l(t('Configure setting here'), 'admin/settings/wordtracker'),
        )
      ), 'error');
    $output = '';
  }
  else {
    $output = '
    <iframe width="673" height="557" scrolling="no" frameborder=0 src="http://nichefinder.wordtracker.com/themes/niche_finder_widget_big.html?name=Test&color_b=#01679a&color_t=#ffffff&embed_id=' . $embed_id . '"></iframe>
    <br/><a href="http://www.wordtracker.com">Powered by WordStream Internet Marketing Software</a>
    ';
  }
  return $output;
}

